summaryrefslogtreecommitdiffstats
path: root/kshowmail/kcmconfigs/configfilter.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
commit9c02dbb59ce57c68dc177d9294b980bf114a3e11 (patch)
treeb1b40423c9be9a42a97cd0e8f3af3139aefb6fa0 /kshowmail/kcmconfigs/configfilter.h
parent0b875800e452c97b1a3f25aba5f029a8c33a4b93 (diff)
downloadkshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.tar.gz
kshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.zip
Update to TDE R14 API
Diffstat (limited to 'kshowmail/kcmconfigs/configfilter.h')
-rw-r--r--kshowmail/kcmconfigs/configfilter.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kshowmail/kcmconfigs/configfilter.h b/kshowmail/kcmconfigs/configfilter.h
index 9d37c82..bcff4ef 100644
--- a/kshowmail/kcmconfigs/configfilter.h
+++ b/kshowmail/kcmconfigs/configfilter.h
@@ -13,17 +13,17 @@
#define CONFIGFILTER_H
//QT headers
-#include <qlayout.h>
-#include <qgroupbox.h>
-#include <qtooltip.h>
-#include <qcheckbox.h>
+#include <ntqlayout.h>
+#include <ntqgroupbox.h>
+#include <ntqtooltip.h>
+#include <ntqcheckbox.h>
//KDE headers
-#include <kcmodule.h>
-#include <kconfig.h>
+#include <tdecmodule.h>
+#include <tdeconfig.h>
#include <kgenericfactory.h>
-#include <kapplication.h>
-#include <klistview.h>
+#include <tdeapplication.h>
+#include <tdelistview.h>
#include <kpushbutton.h>
#include <kcombobox.h>
#include <klineedit.h>
@@ -47,7 +47,7 @@
* @brief Part of the setup dialog (KShowMailApp::SetupDialog) to configure the filter.
* @author Ulrich Weigelt <ulrich.weigelt@gmx.de>
*/
-class ConfigFilter : public KCModule
+class ConfigFilter : public TDECModule
{
Q_OBJECT
@@ -56,7 +56,7 @@ Q_OBJECT
/**
* Generic constructor
*/
- ConfigFilter( QWidget* parent = 0, const char* name = 0, const QStringList &args = QStringList() );
+ ConfigFilter( TQWidget* parent = 0, const char* name = 0, const TQStringList &args = TQStringList() );
/**
* Destructor
@@ -64,21 +64,21 @@ Q_OBJECT
~ConfigFilter();
/**
* Overloaded method of KCModule.
* Sets the user interface elements to reflect the current settings stored in the
* config file.
*/
virtual void load();
/**
* Overloaded method of KCModule.
* Sets the user interface elements to default values.
* This method is called when the user clicks the "Default" button.
*/
virtual void defaults();
/**
* Overloaded method of KCModule.
* Stores the config information as shown in the user interface in the
* config file.
* Is called when the user clicks "Apply" or "Ok".
@@ -90,27 +90,27 @@ Q_OBJECT
/**
* Connector to the configuration file
*/
- KConfig* config;
+ TDEConfig* config;
/**
* Check box to activate the filter
*/
- QCheckBox* chkActivateFilter;
+ TQCheckBox* chkActivateFilter;
/**
* Group box for sender lists.
*/
- QGroupBox* gboxSenderLists;
+ TQGroupBox* gboxSenderLists;
/**
* Group box for filter items.
*/
- QGroupBox* gboxFilters;
+ TQGroupBox* gboxFilters;
/**
* Group box for other action.
*/
- QGroupBox* gboxOthers;
+ TQGroupBox* gboxOthers;
/**
* Button to open the Blacklist.
@@ -125,7 +125,7 @@ Q_OBJECT
/**
* List of filters
*/
- KListView* listFilters;
+ TDEListView* listFilters;
/**
* Button to move a filter at top.
@@ -187,7 +187,7 @@ Q_OBJECT
/**
* Connected with the configuration items.
* Calls the slot changed() of KCModule to notify the dialog about the change.
*/
void slotChanged();
@@ -64,21 +64,21 @@ Q_OBJECT
~ConfigFilter();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Sets the user interface elements to reflect the current settings stored in the
* config file.
@@ -64,21 +64,21 @@ Q_OBJECT
virtual void load();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Sets the user interface elements to default values.
* This method is called when the user clicks the "Default" button.
@@ -64,21 +64,21 @@ Q_OBJECT
virtual void defaults();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Stores the config information as shown in the user interface in the
* config file.
@@ -187,7 +187,7 @@ Q_OBJECT
/**
* Connected with the configuration items.
- * Calls the slot changed() of KCModule to notify the dialog about the change.
+ * Calls the slot changed() of TDECModule to notify the dialog about the change.
*/
void slotChanged();